@@ -20,6 +20,7 @@ writeManifest <- function(appDir = getwd(),
                           appFiles = NULL,
                           appFileManifest = NULL,
                           appPrimaryDoc = NULL,
+                          appMode = NULL,
                           contentCategory = NULL,
                           python = NULL,
                           forceGeneratePythonEnvironment = FALSE,
@@ -38,6 +39,7 @@ writeManifest <- function(appDir = getwd(),
     appFiles = appFiles,
     appPrimaryDoc = appPrimaryDoc,
     quarto = quarto,
+    appMode = appMode,
     contentCategory = contentCategory,
   )
 
